pub struct DirEntries<'a> { /* private fields */ }Expand description
Represents a collection of entries in a directory.
This type provides access to the files and subdirectories within a directory. It can be iterated over or queried by name.
Implementations
Sourceimpl<'a> DirEntries<'a>
impl<'a> DirEntries<'a>
Sourcepub fn get(&self, name: &[u8]) -> Option<&DirEntry<'a>>
pub fn get(&self, name: &[u8]) -> Option<&DirEntry<'a>>
Returns a reference to the entry with the given name.
Sourcepub fn remove(&mut self, name: &[u8]) -> Option<DirEntry<'a>>
pub fn remove(&mut self, name: &[u8]) -> Option<DirEntry<'a>>
Removes and returns the entry with the given name.
Sourcepub fn iter(&self) -> DirEntriesIter<'_, 'a> ⓘ
pub fn iter(&self) -> DirEntriesIter<'_, 'a> ⓘ
Returns an iterator over the entries.